@@ -6,9 +6,10 @@ from functools import wraps
 
 import requests
 
-from flow360 import Env, __version__
-from flow360.cloud.security import api_key
-from flow360.component.utils import is_valid_uuid
+from ..environment import Env
+from ..version import __version__
+
+from .security import api_key
 
 
 def api_key_auth(request):
@@ -62,14 +63,16 @@ class Http:
         self.session = session
 
     @http_interceptor
-    def get(self, path: str, json=None):
+    def get(self, path: str, json=None, params=None):
         """
         Get the resource.
         :param path:
         :param json:
         :return:
         """
-        return self.session.get(url=Env.current.get_real_url(path), auth=api_key_auth, json=json)
+        return self.session.get(
+            url=Env.current.get_real_url(path), auth=api_key_auth, json=json, params=params
+        )
 
     @http_interceptor
     def post(self, path: str, json=None):
@@ -102,38 +105,3 @@ class Http:
 
 
 http = Http(requests.Session())
-
-
-class RestApi:
-    def __init__(self, endpoint, id=None):
-        is_valid_uuid(id, ignore_none=True)
-        self._id = id
-        self._endpoint = endpoint
-        self._info = None
-
-    def _url(self, method):
-        url = f'{self._endpoint}'
-        if self._id is not None:
-            url += f'/{self._id}'
-        if method is not None:
-            url += f'/{method}'
-        return url
-
-
-    def init_id(self, id):
-        if self._id is None:
-            self._id = id
-        else:
-            raise RuntimeError('"id" already set, change of "id" is not allowed.')        
-
-    def get(self, path=None, method=None, json=None):
-        return http.get(path or self._url(method), json=json)
-
-    def post(self, json, path=None, method=None):            
-        return http.post(path or self._url(method), json=json)
-
-    def put(self, json, path=None, method=None):            
-        return http.put(path or self._url(method), json=json)
-
-    def delete(self, path=None, method=None):            
-        return http.put(path or self._url(method))
