@@ -5,6 +5,7 @@ import os
 import urllib
 from datetime import datetime
 from enum import Enum
+from abc import ABC, abstractmethod
 
 import boto3
 from boto3.s3.transfer import TransferConfig
@@ -24,6 +25,23 @@ from rich.progress import (
 from ..environment import Env
 from .http_util import http
 
+
+class ProgressCallbackInterface(ABC):
+    """
+    Progress callback abstract class
+    """
+
+    @abstractmethod
+    def total(self, total: int):
+        """
+        total bytes to transfer
+        """
+
+    @abstractmethod
+    def __call__(self, bytes_chunk_transferred):
+        pass
+
+
 _s3_config = TransferConfig(
     multipart_threshold=1024 * 25,
     max_concurrency=50,
@@ -161,7 +179,9 @@ class S3TransferType(Enum):
 
         return None
 
-    def upload_file(self, resource_id: str, remote_file_name: str, file_name: str):
+    def upload_file(
+        self, resource_id: str, remote_file_name: str, file_name: str, progress_callback=None
+    ):
         """
         Upload a file to s3.
         :param resource_id:
@@ -170,24 +190,37 @@ class S3TransferType(Enum):
         :return:
         """
         if not os.path.exists(file_name):
-            print(f"mesh file {file_name} does not Exist!")
+            print(f"file {file_name} does not Exist!")
             raise FileNotFoundError()
-        with _get_progress(_S3Action.UPLOADING) as progress:
-            task_id = progress.add_task(
-                "upload", filename=os.path.basename(file_name), total=os.path.getsize(file_name)
-            )
 
-            def _call_back(bytes_in_chunk):
-                progress.update(task_id, advance=bytes_in_chunk)
-
-            token = self._get_s3_sts_token(resource_id, remote_file_name)
-            token.get_client().upload_file(
+        token = self._get_s3_sts_token(resource_id, remote_file_name)
+        client = token.get_client()
+        if progress_callback:
+            progress_callback.total = float(os.path.getsize(file_name))
+            client.upload_file(
                 Bucket=token.get_bucket(),
                 Filename=file_name,
                 Key=token.get_s3_key(),
-                Callback=_call_back,
+                Callback=progress_callback,
                 Config=_s3_config,
             )
+        else:
+            with _get_progress(_S3Action.UPLOADING) as progress:
+                task_id = progress.add_task(
+                    "upload", filename=os.path.basename(file_name), total=os.path.getsize(file_name)
+                )
+
+                def _call_back(bytes_in_chunk):
+                    progress.update(task_id, advance=bytes_in_chunk)
+
+                token = self._get_s3_sts_token(resource_id, remote_file_name)
+                client.upload_file(
+                    Bucket=token.get_bucket(),
+                    Filename=file_name,
+                    Key=token.get_s3_key(),
+                    Callback=_call_back,
+                    Config=_s3_config,
+                )
 
     # pylint: disable=too-many-arguments
     def download_file(
@@ -197,6 +230,7 @@ class S3TransferType(Enum):
         to_file: str,
         keep_folder: bool = True,
         overwrite: bool = True,
+        progress_callback=None,
     ):
         """
         Download a file from s3.
@@ -206,6 +240,7 @@ class S3TransferType(Enum):
         :param keep_folder: If true, the downloaded file will be put
         in the same folder as the file on cloud. Only works when to_file is a folder name.
         :param overwrite: if True overwrite if file exists, otherwise don't download
+        :param progress_callback: provide custom callback for progress
         :return:
         """
         to_file = create_base_folder(resource_id, remote_file_name, to_file, keep_folder)
@@ -215,23 +250,32 @@ class S3TransferType(Enum):
         token = self._get_s3_sts_token(resource_id, remote_file_name)
         client = token.get_client()
         meta_data = client.head_object(Bucket=token.get_bucket(), Key=token.get_s3_key())
-        with _get_progress(_S3Action.DOWNLOADING) as progress:
-            progress.start()
-            task_id = progress.add_task(
-                "download",
-                filename=os.path.basename(remote_file_name),
-                total=meta_data.get("ContentLength", 0),
-            )
-
-            def _call_back(bytes_in_chunk):
-                progress.update(task_id, advance=bytes_in_chunk)
-
+        if progress_callback:
+            progress_callback.total = meta_data.get("ContentLength", 0)
             client.download_file(
                 Bucket=token.get_bucket(),
                 Filename=to_file,
                 Key=token.get_s3_key(),
-                Callback=_call_back,
+                Callback=progress_callback,
             )
+        else:
+            with _get_progress(_S3Action.DOWNLOADING) as progress:
+                progress.start()
+                task_id = progress.add_task(
+                    "download",
+                    filename=os.path.basename(remote_file_name),
+                    total=meta_data.get("ContentLength", 0),
+                )
+
+                def _call_back(bytes_in_chunk):
+                    progress.update(task_id, advance=bytes_in_chunk)
+
+                client.download_file(
+                    Bucket=token.get_bucket(),
+                    Filename=to_file,
+                    Key=token.get_s3_key(),
+                    Callback=_call_back,
+                )
 
     def _get_s3_sts_token(self, resource_id: str, file_name: str) -> _S3STSToken:
         session_key = f"{resource_id}:{self.value}:{file_name}"
